import { createWebWorkerMessageTransports } from '@adminide-stack/extension-api/lib/connections/jsonrpc2/transports/webWorker.js';
import { Disposable } from '@workbench-stack/core/lib/services/lifecycle/disposable.js';
import { from, of, Observable } from 'rxjs';
import { logger } from '@cdm-logger/client';
import { LocalStorageSubject } from '../util/local-storage-subject.js';

/* eslint-disable @typescript-eslint/no-unused-vars */
class PlatformContext extends Disposable {
  client;
  _reduxState$;
  services;
  static _instance;
  constructor(client, _reduxState$, services) {
    super();
    this.client = client;
    this._reduxState$ = _reduxState$;
    this.services = services;
    PlatformContext._instance = this;
  }
  get apolloClient() {
    return this.client;
  }
  requestGraphQL(request, variables, mightContainPrivateInfo) {
    return from(PlatformContext._instance.client.watchQuery({
      query: request,
      variables
    }));
  }
  get settings() {
    return of(this.services.configurationService.getValue());
  }
  get orgSettings() {
    return;
  }
  get reduxState$() {
    return this._reduxState$;
  }
  createExtensionHost() {
    logger.info({
      childName: 'PlatformContext'
    }, 'createExtensionHost');
    let worker;
    const isBrowser = typeof document !== 'undefined';
    if (isBrowser) {
      worker = new Worker(new URL('../main.worker.js', import.meta.url), {
        type: 'module'
      });
    } else {
      const scriptFile = '';
      const script = `importScripts('${scriptFile}')`;
      const blob = new Blob([script]);
      worker = new Worker(URL.createObjectURL(blob));
    }
    const messageTransports = createWebWorkerMessageTransports(worker);
    return new Observable(sub => {
      sub.next(messageTransports);
      return () => worker.terminate();
    });
  }
  getScriptURLForExtension = bundleURL => bundleURL;
  get sideloadedExtensionURL() {
    return new LocalStorageSubject('sideloadedExtensionURL', null);
  }
  cdeopsURL = 'http://localhost:8080' /*(window.context as any).externalURL,*/;
  clientApplication;
  traceExtensionHostCommunication = new LocalStorageSubject('traceExtensionHostCommunication', false);
}

export { PlatformContext };
//# sourceMappingURL=context.js.map
